ska.contrib.django.ska.urls package
===================================

Submodules
----------

ska.contrib.django.ska.urls.constance\_urls module
--------------------------------------------------

.. automodule:: ska.contrib.django.ska.urls.constance_urls
    :members:
    :undoc-members:
    :show-inheritance:

ska.contrib.django.ska.urls.default\_urls module
------------------------------------------------

.. automodule:: ska.contrib.django.ska.urls.default_urls
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ska.contrib.django.ska.urls
    :members:
    :undoc-members:
    :show-inheritance:
